## R codes of the article:

## Hitchhikers’ guide to analysing bird ringing data
## Part 2: distributions, summary statistics and outliers
## Harnos, A, Fehérvári, P. & Csörgő, T.
## Ornis Hungarica 2016. 24(1): 172-181.

## ----Load the ringR package------------------------------------
library(ringR)

## ----Set the working directory---------------------------------------
mydirectory="/home/andrea/mydir"
setwd(mydirectory)

## ----Import data from a text file-------------------------------------
mydata = read.table(
   file = "FICHYP1.csv", #the name of the file
   sep = ";",           #the field separator character
   dec = ".",           #the character used in the file for decimal points
   header = TRUE) #a logical value indicating whether the file 
                   #contains the names of the variables in the first line
  

## ----Structure of the table----------------------------------------------
str(mydata)


## ---Import distr_data and calculate numerical summeries------------------------------------------------
options(digits=3)
library(RcmdrMisc)
distr_data=read.table("distr_data.csv",sep=";",header=T)
numSummary(distr_data,statistics=c("mean","sd","cv","quantiles"))

## -----Outliers-------------------------------------------------------------------
#subset juvenile, female birds from the autumn migration period
mydata_1 = subset(mydata,(mydata$age == "juv" & mydata$SEX == "F" & mydata$season == "autumn"))

#outliers
boxplot.stats(mydata_1$WING)$out

Q1 = quantile(mydata_1$WING, na.rm = T)[2]   #1st quartile
Q3 = quantile(mydata_1$WING, na.rm = T)[4]   #3rd quartile
IQR = IQR(mydata_1$WING, na.rm = T)  #Interquartile range
const = 1.5

#subsetting outliers
outliers = subset(mydata_1, (mydata_1$WING < (Q1-const*IQR) | mydata_1$WING > (Q3+const*IQR)))
#print outliers
outliers

## ------------Scatterplot------------------------------------------------------------
library(car)

scatterplot(jitter(WING)~jitter(THIRD), data=mydata, smooth=F, subset=(season=="autumn" & SEX == "M" & age == "juv"), reg.line=F, ellipse=T, levels=c(0.95, 0.99), id.method="identify",)




